<?php

    class xx_xml{

        /**
         * 将数组转换为xml
         * @param array $arr:数组
         * @param object $dom:Document对象，默认null即可
         * @param object $node:节点对象，默认null即可
         * @param string $root:根节点名称
         * @param string $cdata:是否加入CDATA标签，默认为false
         * @return string
         */
        public static function arrayToXml($arr,$dom=null,$node=null,$root='xml',$cdata=false){

            if (!$dom){
                $dom = new DOMDocument('1.0','utf-8');
            }
            if(!$node){
                $node = $dom->createElement($root);
                $dom->appendChild($node);
            }
            foreach ($arr as $key=>$value){
                $child_node = $dom->createElement(is_string($key) ? $key : 'node');
                $node->appendChild($child_node);
                if (!is_array($value)){
                    if (!$cdata) {
                        $data = $dom->createTextNode($value);
                    }else{
                        $data = $dom->createCDATASection($value);
                    }
                    $child_node->appendChild($data);
                }else {
                    self::arrayToXml($value,$dom,$child_node,$root,$cdata);
                }
            }
            return $dom->saveXML();
        }
        /**
         * 将xml转换为数组
         * @param string $xml:xml文件或字符串
         * @return array
         */
        public static function xmlToArray($xml){
            //考虑到xml文档中可能会包含<![CDATA[]]>标签，第三个参数设置为LIBXML_NOCDATA
            if (file_exists($xml)) {
                libxml_disable_entity_loader(false);
                $xml_string = simplexml_load_file($xml,'SimpleXMLElement', LIBXML_NOCDATA);
            }else{
                libxml_disable_entity_loader(true);
                $xml_string = simplexml_load_string($xml,'SimpleXMLElement', LIBXML_NOCDATA);
            }
            $result = json_decode(json_encode($xml_string),true);
            return $result;
        }

        public static function xml_output($result){//xml格式输出
            header('Content-Type:text/xml');
            $xml = "<?xml version='1.0' encoding='UTF-8'?>\n";
            $xml .= "<root>";
            $xml .= self::encodeXml($result);
            $xml .= "</root>";
            return $xml;
        }

        /**
         *将数据解析为XML字符串
         */

        protected static function encodeXml($data){
            $attr = $xml = "";
            foreach($data as $key => $value){
                if(is_numeric($key)){
                    $attr = " id='{$key}'";
                    $key = "item";
                }
                $xml .= "<{$key}{$attr}>";
                $xml .= is_array($value)?self::encodeXml($value):$value;
                $xml .= "</$key>";
            }
            return $xml;
        }
    }